Module args

Module args 

This module provides types and traits for working with entrypoint arguments.

Structs

BatchUpgradeArgs
A type representing arguments for batch upgrading child contracts.

Enums

Maybe
A type that represents an entrypoint arg that may or may not be present.

Traits

EntrypointArgument
A trait for types that can be used as entrypoint arguments.

Functions

odra_argument
Returns an Odra’s entrypoint argument representation.
parameter
Returns a Casper entrypoint argument representation. If the parameter is not required, it returns None.