HasEntrypoints

Trait HasEntrypoints 

pub trait HasEntrypoints {
    // Required method
    fn entrypoints() -> Vec<Entrypoint>;
}
A trait that should be implemented by each smart contract to allow the backend to generate blockchain-specific code.

Required Methods

fn entrypoints() -> Vec<Entrypoint>

Returns the list of contract’s entrypoints.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors